'use strict'

const test = require('tape')
const cp = require('child_process')
const path = require('path')
const concat = require('terminus').concat

const proxy_js = path.join(__dirname, '..', 'proxy.js')

runTests()

function runTests () {
  test('display help', function (t) {
    const args = [
      proxy_js,
      '--loglevel',
      'debug'
    ]

    function checkResults (buffer) {
      const types = {
        debug: 0,
        info: 0,
        warn: 0,
        error: 0
      }
      const lines = buffer.toString().trim().split('\n')
      for (var i = 0; i < lines.length; i++) {
        let content = JSON.parse(lines[i])
        types[content.level]++
      }
      t.ok(types.debug > 0, 'there are more than 0 debug messages')
      t.ok(types.info > 0, 'there are more than 0 info messages')
      t.ok(types.warn > 0, 'there are more than 0 warn messages')
      t.ok(types.error === 0, 'there are no error messages')
      t.end()
    }

    const child = cp.spawn('node', args)

    child.stdout.pipe(concat(checkResults))

    setTimeout(function () {
      child.kill('SIGINT')
    }, 500)
  })
}
