import hyperquest from 'hyperquest'
import concat from 'concat-stream'

module.exports = notify

function notify (appConfig, payload, fn) {
  const url = appConfig.rc.notificationEndpoint.url

  const stream = hyperquest.post(url, {
    headers: {
      'x-nsolid-license-key': appConfig.rc.license.key
    }
  })

  stream.end(JSON.stringify(payload))

  stream.on('error', fn)

  stream.on('response', function handleNotifyResponse (res) {
    if (res.statusCode === 202) {
      fn()
    } else {
      const contentType = res.headers['content-type']
      res.pipe(concat((body) => {
        body = String(body)
        let errorMessage = body
        if (contentType === 'application/json') {
          errorMessage = tryGetJSONError(body)
        }
        fn(new Error(`Sending Notification Failed with Status ${res.statusCode}:\n${errorMessage}`))
      }))
    }
  })
}

function tryGetJSONError (body) {
  try {
    return JSON.parse(body).errorMessage
  } catch (err) {
    // ignore err
  }
  return body
}
