import test from 'tape'
import tmp from 'tmp'
import path from 'path'
import fs from 'fs'
import mkdirp from 'mkdirp'
import through from 'through'
import createSnapshot from '../snapshot'
import config from '../../config'
import createTestCleanup from '../../test/_cleanup'
import createNetwork from '../../test/_create-network'
import createNSolidAgent from '../../test/_nsolid-agent'
import Cache from '../../cache'

tmp.setGracefulCleanup()

test('actions/snapshot - create snapshot', createTestCleanup(t => {
  const app = 'snapshot-generators'
  const id = 'the-one-we-care-about'
  const tmpobj = tmp.dirSync({ unsafeCleanup: true })
  const snapshotPath = path.join(tmpobj.name, 'snapshots')
  mkdirp.sync(snapshotPath)

  createNetwork(t, app, 1)(function (e, network) {
    t.error(e, 'created network')
    const conf = config(['--hub', network.proxyUrl])
    const cache = new Cache(tmpobj.name)

    createNSolidAgent(t, network, app, id, (agentError, listener) => {
      t.error(agentError, 'created agent')

      const expect = {
        snapshot: true
      }

      listener.on('snapshot', (req, nop, next) => {
        const stream = through()
        next(null, stream)

        process.nextTick(() => {
          stream.end(JSON.stringify(expect))
        })

        return true
      })

      const proc = {
        app: app,
        id: id,
        hub: network.proxyUrl,
        title: 'Mr Snapshots',
        pid: 123
      }

      cache.addProcess(proc)

      createSnapshot(cache, conf, proc, (e, meta) => {
        t.error(e, 'created snapshot')
        t.equal(meta.pid, 123, 'pid matches')
        t.equal(meta.title, 'Mr Snapshots', 'title matches')

        fs.readFile(path.join(snapshotPath, meta.file), { encoding: 'utf8' }, (e, str) => {
          const obj = JSON.parse(str)
          t.deepEqual(obj, expect, 'loaded from disk')
          t.end()
        })
      })
    })
  })
}))
