import createGraph from '../graph-cache'
import computeAppId from '../../compute-app-id'
import camelize from 'camelize'

module.exports = computeSparklines

function computeSparklines (config, application, hosts, duration) {
  var storeTime = (duration * 1000 * 60)

  const rc = config.rc
  const appid = computeAppId(application.name)

  if (rc) {
    const thresholds = config.rc.thresholds

    if (thresholds && thresholds.app && thresholds.app[appid]) {
      const appThresholds = thresholds.app[appid]
      const appGraph = createGraph({type: 'app', id: appid}, storeTime)

      Object.keys(appThresholds).forEach((metricName) => {
        const thresholdConfig = appThresholds[metricName]
        if (!thresholdConfig) {
          return
        }

        let threshold = thresholdConfig.threshold
        if (!thresholdConfig.enabled) {
          threshold = null
        }

        // camelize threshold-cpu to thresholdCpu for cleaner access on the frontend
        const graphName = camelize('threshold-' + metricName)

        appGraph.add(graphName, threshold)
      })
    }
  }

  application.processes.forEach(function eachProcess (proc) {
    var hostname = proc.host
    var host = hosts[hostname]
    var processGraph = createGraph({type: 'process', id: proc.id}, storeTime)
    var hostGraph = createGraph({type: 'host', id: hostname}, storeTime)

    if (!host.computedSparklines) {
      host.computedSparklines = true
      hostGraph.add('load1m', host.stats.load1m)
      hostGraph.add('memoryPercentageUsed', host.stats.memoryPercentageUsed)
    }

    var hostData = hostGraph.get('load1m')

    processGraph.add('cpu', proc.cpu, hostData)
    processGraph.add('rss', proc.memory.rss, hostData)
    processGraph.add('heapTotal', proc.memory.total, hostData)
    processGraph.add('heapUsed', proc.memory.used, hostData)
    processGraph.add('asyncHandles', proc.async.handles, hostData)
    processGraph.add('asyncRequests', proc.async.requests, hostData)
  })
}
