/**
 * Simple nsolid-console profiling tool.
 * Starts then stops React's Perf profiling.
 * Waits for a `applications` event before starting.
 * Profiling continues for `events` number of 'applications' events.
 * On completion will print a summary of 'wasted' renders.
 * i.e. React component renders that resulted in exactly the same DOM output.
 */

export default function profile ({minTime, events} = {events: 5}) {
  if (!window.nsolid) return
  events = events || 5
  const nsolid = window.nsolid
  console.info(`starting profiling on next 'applications' event for ${events} events.`)
  nsolid.on('applications', function profileStart () {
    console.info('starting profiling...')
    console.time('profiled for')
    nsolid.off('applications', profileStart)
    nsolid.Perf.start()
    let eventCount = 0
    nsolid.on('applications', function profileEnd () {
      if (eventCount) console.timeEnd(`applications event ${eventCount}`)
      eventCount++
      console.time(`applications event ${eventCount}`)
      if (eventCount <= events) return
      nsolid.off('applications', profileEnd)
      nsolid.Perf.printWasted()
      const wasted = nsolid.Perf.getMeasurementsSummaryMap(nsolid.Perf.getLastMeasurements())
      if (wasted.length === 0) console.info('Great, no wasted renders.')
      nsolid.Perf.stop()
      console.timeEnd('profiled for')
    })
  })
}
